@@ -1,18 +1,28 @@
+"""
+Interpolates data specified in 'names' to time values found in 'interp_to'.
+
+Notes
+-----
+Allowed wildcards are ? for a single character, * from multiple characters.
+Similar to tinterpol.pro in IDL SPEDAS.
 
 """
-File:
-    tinterpol.py
+from pyspedas import tnames
+from pytplot import get_data, store_data
 
-Description:
-    Interpolates data specified in 'names' to time values found in 'interp_to'.
 
-Parameters:
+def tinterpol(names, interp_to, method=None, newname=None, suffix=None):
+    """
+    Interpolate data to times in interp_to.
+
+    Parameters
+    ----------
     names: str/list of str
         List of variables to interpolate.
     interp_to: str
         String containing the variable
             containing the time stamps to interpolate to
-    method: str
+    method: str, optional
         Interpolation method. Default is ‘linear’.
         Specifies the kind of interpolation as a string (‘linear’, ‘nearest’,
         ‘zero’, ‘slinear’, ‘quadratic’, ‘cubic’, ‘previous’, ‘next’)
@@ -20,25 +30,18 @@ Parameters:
         interpolation of zeroth, first, second or third order; ‘previous’ and
         ‘next’ simply return the previous or next value of the point) or
         as an integer specifying the order of the spline interpolator to use.
-    newname: str/list of str
+    newname: str/list of str, optional
         List of new_names for pytplot variables.
         If '', then pytplot variables are replaced.
         If not given, then a suffix is applied.
-    suffix:
+    suffix: str, optional
         A suffix to apply. Default is '-itrp'.
 
-Notes:
-    Allowed wildcards are ? for a single character, * from multiple characters.
-    Similar to tinterpol in IDL SPEDAS.
-"""
-
-from pyspedas import tnames
-from pytplot import get_data, store_data
-import pytplot
-
-
-def tinterpol(names, interp_to, method=None, newname=None, suffix=None):
+    Returns
+    -------
+    None.
 
+    """
     if not isinstance(names, list):
         names = [names]
     if not isinstance(newname, list):
@@ -50,13 +53,13 @@ def tinterpol(names, interp_to, method=None, newname=None, suffix=None):
         print('tinterpol error: No pytplot names were provided.')
         return
 
-    if suffix == None:
+    if suffix is None:
         suffix = '-itrp'
 
-    if method == None:
+    if method is None:
         method = 'linear'
 
-    if (newname == None) or (len(newname) == 1 and newname[0] == None):
+    if (newname is None) or (len(newname) == 1 and newname[0] is None):
         n_names = [s + suffix for s in old_names]
     elif newname == '':
         n_names = old_names
@@ -65,15 +68,16 @@ def tinterpol(names, interp_to, method=None, newname=None, suffix=None):
 
     interp_to_data = get_data(interp_to)
 
-    if interp_to_data == None:
+    if interp_to_data is None:
         print('Error, tplot variable: ' + interp_to + ' not found.')
         return
 
     interp_to_times = interp_to_data[0]
 
     for name_idx, name in enumerate(old_names):
-        xdata = pytplot.data_quants[name]
-        xdata_interpolated = xdata.interp({'time': interp_to_times.tolist()},method=method)
+        xdata = get_data(name, xarray=True)
+        xdata_interpolated = xdata.interp({'time': interp_to_times},
+                                          method=method)
 
         if 'spec_bins' in xdata.coords:
             store_data(n_names[name_idx],
