@@ -55,7 +55,7 @@ def mms_load_fgm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
     level='l2', instrument='fgm', datatype='', varformat=None, suffix='',
     keep_flagged=False, get_support_data=True, time_clip=False, no_update=False,
     available=False, notplot=False, latest_version=False, major_version=False, 
-    min_version=None, cdf_version=None, spdf=False):
+    min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
     This function loads FGM data into tplot variables
     
@@ -123,6 +123,10 @@ def mms_load_fgm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
             If True, don't remove flagged data (flagged data are set to NaNs by
             default, this keyword turns this off)
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
             
@@ -139,7 +143,7 @@ def mms_load_fgm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument=instrument,
             datatype=datatype, varformat=varformat_fetch, suffix=suffix, get_support_data=get_support_data,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, major_version=major_version, 
-            min_version=min_version, cdf_version=cdf_version, spdf=spdf)
+            min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
     
     if tvars == None or available or notplot or CONFIG['download_only']:
         return tvars
@@ -167,7 +171,8 @@ def mms_load_fgm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 def mms_load_hpca(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
     level='l2', datatype='moments', get_support_data=None, time_clip=False, no_update=False,
     varformat=None, suffix='', center_measurement=False, available=False, notplot=False, 
-    latest_version=False, major_version=False, min_version=None, cdf_version=None, spdf=False):
+    latest_version=False, major_version=False, min_version=None, cdf_version=None, spdf=False,
+    always_prompt=False):
     """
     This function loads HPCA data into tplot variables
     
@@ -236,6 +241,10 @@ def mms_load_hpca(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srv
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
             
@@ -251,7 +260,7 @@ def mms_load_hpca(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srv
             datatype=datatype, varformat=varformat, suffix=suffix, get_support_data=get_support_data,
             time_clip=time_clip, no_update=no_update, center_measurement=center_measurement, available=available, 
             latest_version=latest_version, major_version=major_version, min_version=min_version, cdf_version=cdf_version,
-            spdf=spdf)
+            spdf=spdf, always_prompt=always_prompt)
     
     if tvars == None or available or notplot or CONFIG['download_only']:
         return tvars
@@ -264,7 +273,7 @@ def mms_load_fpi(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
     level='l2', datatype=['des-moms', 'dis-moms'], varformat=None, suffix='',
     get_support_data=False, time_clip=False, no_update=False, center_measurement=False,
     available=False, notplot=False, latest_version=False, major_version=False, 
-    min_version=None, cdf_version=None, spdf=False):
+    min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
     This function loads FPI data into tplot variables
     
@@ -335,6 +344,10 @@ def mms_load_fpi(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
             
@@ -347,7 +360,7 @@ def mms_load_fpi(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
             datatype=datatype, varformat=varformat, suffix=suffix, get_support_data=get_support_data,
             time_clip=time_clip, no_update=no_update, center_measurement=center_measurement, available=available, 
             notplot=notplot, latest_version=latest_version, major_version=major_version, min_version=min_version, 
-            cdf_version=cdf_version, spdf=spdf)
+            cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
     
     if tvars == None or available or notplot or CONFIG['download_only']:
         return tvars
@@ -360,7 +373,7 @@ def mms_load_fpi(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
 def mms_load_scm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
     level='l2', datatype='', varformat=None, suffix='', get_support_data=False,
     time_clip=False, no_update=False, available=False, notplot=False, latest_version=False, 
-    major_version=False, min_version=None, cdf_version=None, spdf=False):
+    major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
     This function loads SCM data into tplot variables
     
@@ -425,6 +438,10 @@ def mms_load_scm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
 
@@ -455,7 +472,8 @@ def mms_load_scm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='scm',
             datatype=datatype, varformat=varformat, suffix=suffix, get_support_data=get_support_data,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
-            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf)
+            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, 
+            always_prompt=always_prompt)
 
     if tvars == None or available or notplot or CONFIG['download_only']:
         return tvars
@@ -486,7 +504,7 @@ def mms_load_scm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 def mms_load_mec(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
     level='l2', datatype='ephts04d', varformat=None, suffix='', get_support_data=False,
     time_clip=False, no_update=False, available=False, notplot=False, latest_version=False, 
-    major_version=False, min_version=None, cdf_version=None, spdf=False):
+    major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
     This function loads MEC data into tplot variables
     
@@ -550,6 +568,10 @@ def mms_load_mec(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
             
@@ -561,7 +583,7 @@ def mms_load_mec(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
             datatype=datatype, get_support_data=get_support_data, varformat=varformat, suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, notplot=notplot, 
             latest_version=latest_version, major_version=major_version, min_version=min_version, 
-            cdf_version=cdf_version, spdf=spdf)
+            cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
 
     if tvars == None or available or notplot or CONFIG['download_only']:
         return tvars
@@ -574,7 +596,7 @@ def mms_load_mec(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
     level='l2', datatype='electron', varformat=None, get_support_data=True, suffix='', time_clip=False,
     no_update=False, available=False, notplot=False, no_flatfield_corrections=False, data_units=['count_rate', 'intensity'], 
-    latest_version=False, major_version=False, min_version=None, cdf_version=None, spdf=False):
+    latest_version=False, major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
     This function loads FEEPS data into tplot variables
     
@@ -640,6 +662,10 @@ def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
 
@@ -650,7 +676,7 @@ def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='feeps',
             datatype=datatype, varformat=varformat, get_support_data=get_support_data, suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
-            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf)
+            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
 
     if tvars == [] or available or notplot or CONFIG['download_only']:
         return tvars
@@ -689,7 +715,8 @@ def mms_load_feeps(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
 @print_vars
 def mms_load_eis(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', level='l2', datatype='extof',
         varformat=None, get_support_data=True, suffix='', time_clip=False, no_update=False,
-        available=False, notplot=False, latest_version=False, major_version=False, min_version=None, cdf_version=None, spdf=False):
+        available=False, notplot=False, latest_version=False, major_version=False, min_version=None, cdf_version=None, 
+        spdf=False, always_prompt=False):
     """
     This function loads EIS data into tplot variables
     
@@ -753,6 +780,10 @@ def mms_load_eis(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
 
@@ -764,7 +795,7 @@ def mms_load_eis(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='epd-eis',
             datatype=datatype, varformat=varformat, get_support_data=get_support_data, prefix='', suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
-            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf)
+            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
 
     if tvars == [] or available or notplot or CONFIG['download_only']:
         return tvars
@@ -861,7 +892,7 @@ def mms_load_eis(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 def mms_load_edi(trange=['2016-10-16', '2016-10-17'], probe='1', data_rate='srvy', level='l2', datatype='efield',
         varformat=None, get_support_data=False, suffix='', time_clip=False, no_update=False,
         available=False, notplot=False, latest_version=False, major_version=False, min_version=None, cdf_version=None, 
-        spdf=False):
+        spdf=False, always_prompt=False):
     """
     This function loads EDI data into tplot variables
     
@@ -925,6 +956,10 @@ def mms_load_edi(trange=['2016-10-16', '2016-10-17'], probe='1', data_rate='srvy
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
 
@@ -935,7 +970,7 @@ def mms_load_edi(trange=['2016-10-16', '2016-10-17'], probe='1', data_rate='srvy
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='edi',
             datatype=datatype, varformat=varformat, get_support_data=get_support_data, suffix=suffix, time_clip=time_clip, 
             no_update=no_update, available=available, latest_version=latest_version, major_version=major_version, 
-            min_version=min_version, cdf_version=cdf_version, spdf=spdf)
+            min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
 
     if tvars == None or available or notplot or CONFIG['download_only']:
         return tvars
@@ -948,7 +983,7 @@ def mms_load_edi(trange=['2016-10-16', '2016-10-17'], probe='1', data_rate='srvy
 def mms_load_edp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast', level='l2', datatype='dce',
         varformat=None, get_support_data=False, suffix='', time_clip=False, no_update=False,
         available=False, notplot=False, latest_version=False, major_version=False, min_version=None, cdf_version=None, 
-        spdf=False):
+        spdf=False, always_prompt=False):
     """
     This function loads EDP data into tplot variables
     
@@ -1012,6 +1047,10 @@ def mms_load_edp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
 
@@ -1022,7 +1061,8 @@ def mms_load_edp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='edp',
             datatype=datatype, varformat=varformat, get_support_data=get_support_data, suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
-            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf)
+            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, 
+            always_prompt=always_prompt)
     
     if tvars == None or available or notplot or CONFIG['download_only']:
         return tvars
@@ -1035,7 +1075,7 @@ def mms_load_edp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='fast
 def mms_load_dsp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
     level='l2', datatype='bpsd', varformat=None, suffix='', get_support_data=False,
     time_clip=False, no_update=False, available=False, notplot=False, latest_version=False, 
-    major_version=False, min_version=None, cdf_version=None, spdf=False):
+    major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
     This function loads DSP data into tplot variables
     
@@ -1099,6 +1139,10 @@ def mms_load_dsp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
 
@@ -1109,7 +1153,7 @@ def mms_load_dsp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='dsp',
             datatype=datatype, varformat=varformat, suffix=suffix, get_support_data=get_support_data, time_clip=time_clip, 
             no_update=no_update, available=available, latest_version=latest_version, major_version=major_version, 
-            min_version=min_version, cdf_version=cdf_version, spdf=spdf)
+            min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
     
     if tvars == None or available or notplot or CONFIG['download_only']:
         return tvars
@@ -1122,7 +1166,7 @@ def mms_load_dsp(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy
 def mms_load_aspoc(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', 
     level='l2', datatype='', varformat=None, get_support_data=False, suffix='', time_clip=False, no_update=False,
     available=False, notplot=False, latest_version=False, major_version=False, min_version=None, cdf_version=None, 
-    spdf=False):
+    spdf=False, always_prompt=False):
     """
     This function loads ASPOC data into tplot variables
     
@@ -1186,6 +1230,10 @@ def mms_load_aspoc(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
 
@@ -1196,14 +1244,15 @@ def mms_load_aspoc(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='sr
     tvars = mms_load_data(trange=trange, notplot=notplot, probe=probe, data_rate=data_rate, level=level, instrument='aspoc',
             datatype=datatype, varformat=varformat, get_support_data=get_support_data, suffix=suffix,
             time_clip=time_clip, no_update=no_update, available=available, latest_version=latest_version, 
-            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf)
+            major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, 
+            always_prompt=always_prompt)
     return tvars
 
 @print_vars
 def mms_load_fsm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='brst', 
     level='l3', datatype='8khz', get_support_data=False, time_clip=False, no_update=False, 
     available=False, varformat=None, notplot=False, suffix='', latest_version=False, 
-    major_version=False, min_version=None, cdf_version=None, spdf=False):
+    major_version=False, min_version=None, cdf_version=None, spdf=False, always_prompt=False):
     """
     This function loads FSM data into tplot variables
     
@@ -1262,6 +1311,10 @@ def mms_load_fsm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='brst
         major_version: bool
             Only open the latest major CDF version (e.g., X in vX.Y.Z) in the requested time interval
 
+        always_prompt: bool
+            Set this keyword to always prompt for the user's username and password;
+            useful if you accidently save an incorrect password, or if your SDC password has changed
+            
         spdf: bool
             If True, download the data from the SPDF instead of the SDC
 
@@ -1272,7 +1325,7 @@ def mms_load_fsm(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='brst
     tvars = mms_load_data(trange=trange, notplot=notplot, varformat=varformat, probe=probe, data_rate=data_rate, 
         level=level, instrument='fsm', datatype=datatype, get_support_data=get_support_data, time_clip=time_clip, 
         no_update=no_update, available=available, suffix=suffix, latest_version=latest_version, 
-        major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf)
+        major_version=major_version, min_version=min_version, cdf_version=cdf_version, spdf=spdf, always_prompt=always_prompt)
     return tvars
 
 '''
